@@ -174,7 +174,7 @@ char *pt;
       if(strstr(md[i]+1, "wh") && !strstr(md[i]+1, "whi") && strncmp(md[i]+1, "wh", 2) != 0) return;
       if(strncmp(md[i]+1, "whether ", 8) == 0) return;
       if(strncmp(md[i]+1, "many ", 5) == 0) return;
-      if(strncmp(md[i]+1, "only ", 5) == 0) goto JMP1;
+      if(strncmp(md[i]+1, "only ", 5) == 0 || strncmp(md[i]+1, "nation", 6) == 0) goto JMP1; // the
       if(strchr(mz[i], 'y') ) goto JMP2;
       if(strchr(mz[i], 'K') && strchr(mz[i], 'B')) return;
       if(strchr(mz[i], 'K') || strchr(mz[i], 'n') || strchr(mz[i], 'x') || strchr(mz[i], 't') || strstr(mz[i], "X") || strstr(mz[i], "") )
@@ -241,6 +241,10 @@ char *pt;
       }
       else ninsyo(md[i], mz[i], md[i], mz[i]);
     }
+    if(strncmp(cmd, "&J-1", 4) == 0){
+      j = -1;
+      ninsyo(md[i], mz[i], md[j], mz[j]);    return;
+    }
     if(strncmp(cmd, "&J", 2) == 0){
       j = *(pt+3) - '0';
       ninsyo(md[i], mz[i], md[j], mz[j]);    return;
@@ -449,11 +453,12 @@ char mdi[], mzi[], mdj[], mzj[];
     }
     else{
     if(Dbg == 'Y') fprintf(dbg, "--- ninsyo --- 1 %s %s \n", mdj+1, mzj);
+      if(strcmp(mdjb, "SJ") == 0){ strcpy(mdj, sj);  strcpy(mzj, sz); }
       if(strchr(mzi, 'p')) return;
       if(strstr(mzj, "") || strchr(mzj, 'n') || strchr(mzj, 'x')) return;
       if(strcmp(mdj+1, "I") == 0 || strcmp(mdj+1, "you") == 0) return;
       if(strcmp(mdj+1, "we") == 0 || strcmp(mdj+1, "they") == 0) return;
-      if(strstr(mdj+1, "men")) return;
+      if(strstr(mdj+1, "men") || strstr(mdj+1, " and ")) return;
       else if(strstr("he,she,it", mdj+1) || strstr(mzj, "") == 0 || strchr(mzj, 'z') ){
     if(Dbg == 'Y') fprintf(dbg, "--- ninsyo --- 2 %s \n", mdj+1);
         if(strcmp(mdi+1, "often happen") == 0){
@@ -752,7 +757,8 @@ char yk[];
     else if(strncmp(yk+1, "may", 3) == 0) ptinsert(yk+4, " not");
     else if(strncmp(yk+1, "must", 4) == 0) ptinsert(yk+5, " not");
     else if(strncmp(yk+1, "will", 4) == 0) ptinsert(yk+5, " not");
-    else if(strncmp(yk+1, "be", 2) == 0 && strncmp(yk+1, "bec", 3)) ptinsert(yk+3, " not");
+    else if(strncmp(yk+1, "be ", 3) == 0) ptinsert(yk+4, "not");
+    else if(strncmp(yk+1, "be", 2) == 0 && strlen(yk+1) == 2) ptinsert(yk+3, " not");
     else if(strncmp(yk+1, "is ", 3) == 0) ptinsert(yk+3, " not");
     else if(strncmp(yk+1, "was ", 4) == 0) ptinsert(yk+4, " not");
     else if(strncmp(yk+1, "are ", 4) == 0) ptinsert(yk+4, " not");
